/*
 * Reactions
 *
 * Copyright 2016-present Yannick Loriot.
 * http://yannickloriot.com
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 */

/**
 These constants specify reaction feedback when interacting with the `ReactionSelector`.
 */
public enum ReactionFeedback {
  /// Slide finger across feedback
  case slideFingerAcross
  /// Release to cancel feedback
  case releaseToCancel
  /// Tap to select a reaction feedback
  case tapToSelectAReaction

  // MARK: - Getting a Localized Feedback Description

  /// A string containing the localized description of the feedback.
  public var localizedString: String {
    switch self {
    case .slideFingerAcross:
      return "feedback.slideFingerAcross".localized()
    case .releaseToCancel:
      return "feedback.releaseToCancel".localized()
    case .tapToSelectAReaction:
      return "feedback.tapToSelectAReaction".localized()
    }
  }
}
